Rdocumentation
powered by
Learn R Programming
pulseTD (version 0.1.0)
rpkmres: a list containing the expression values of exons and introns
Description
a list containing the expression values of exons and introns
Arguments
Format
A list